<?php
/**
 * Plugin Name: Pakketdienst QLS Servicepoint Locator
 * Plugin URI: https://pakketdienstqls.nl
 * Description: Pakketdienst QLS Servicepoint Locator plugin
 * Version: 1.3
 * Author: Pakketdienst QLS B.V.
 * Author URI: https://profiles.wordpress.org/pakketdienstqls
 * Requires at least: 4.8.0
 * Tested up to: 4.8.2
 */

if (!defined('ABSPATH')) {
    exit();
}

class WC_Qls_Servicepoint_Shipping_Method extends WC_Shipping_Flat_Rate
{
    public $plugin_id = 'qls_';
    
    /**
     * Constructor for your shipping class
     *
     * @access public
     * @return void
     */
    public function __construct($instance_id = 0)
    {
        $this->id = 'qlssp';
        $this->method_title = 'Afhalen op servicepunt';
        $this->method_description = 'Maakt het mogelijk om een bestelling af te halen bij een servicepunt';
        $this->instance_id = absint($instance_id);
        $this->supports = array(
            'shipping-zones',
            'instance-settings',
            'instance-settings-modal',
        );
        $this->init();
    }
    
    /**
     * Init your settings
     *
     * @access public
     * @return void
     */
    function init()
    {
        // Load the settings API
        $this->init_form_fields(); // This is part of the settings API. Override the method to add your own settings
        
        $this->instance_form_fields = include(WC()->plugin_path() . '/includes/shipping/flat-rate/includes/settings-flat-rate.php');
        $this->addExtraFields($this->instance_form_fields);
        $this->title = $this->get_option('title');
        $this->tax_status = $this->get_option('tax_status');
        $this->cost = $this->get_option('cost');
        $this->type = $this->get_option('type', 'class');
        
        $this->free_shipping_enabled = $this->get_option('free_shipping_enabled');
        $this->free_shipping_min_amount = $this->get_option('free_shipping_min_amount');
        $this->qls_company_id = $this->get_option('qls_company_id');
        
        // Save settings in admin if you have any defined
        add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
    }
    
    public function init_form_fields()
    {
        parent::init_form_fields();
        $this->addExtraFields($this->form_fields);
    }
    
    /**
     * calculate_shipping function.
     *
     * @access public
     * @param mixed $package
     * @return void
     */
    public function calculate_shipping($package = array())
    {
        if ($this->hasFreeDelivery()) {
            $this->add_rate(array(
                'id' => $this->id,
                'label' => $this->title,
                'cost' => 0,
                'taxes' => false,
                'package' => $package,
            ));
        } else {
            parent::calculate_shipping($package);
        }
    }
    
    private function hasFreeDelivery()
    {
        if ($this->free_shipping_enabled === 'yes') {
            $total = WC()->cart->get_displayed_subtotal();
            if ('incl' === WC()->cart->tax_display_cart) {
                $total = $total - (WC()->cart->get_cart_discount_total() + WC()->cart->get_cart_discount_tax_total());
            } else {
                $total = $total - WC()->cart->get_cart_discount_total();
            }
            
            if ($total >= $this->free_shipping_min_amount) {
                return true;
            }
        }
        return false;
    }
    
    private function addExtraFields(&$form_fields)
    {
        $form_fields['title']['default'] = $this->method_title;
        $form_fields['free_shipping_enabled'] = array(
            'title' => 'Gratis verzending',
            'type' => 'select',
            'class' => 'wc-enhanced-select',
            'default' => '',
            'options' => array(
                'no' => 'Nee',
                'yes' => 'Ja',
            ),
        );
        $form_fields['free_shipping_min_amount'] = array(
            'title' => 'Minimale bestel waarde voor gratis verzending',
            'type' => 'price',
            'placeholder' => wc_format_localized_price(0),
            'description' => 'Indien ingeschakeld, kan de klant zonder extra kosten zijn bestelling laten bezorgen bij een servicepunt.',
            'default' => '50',
            'desc_tip' => true,
        );

        $form_fields['qls_company_id'] = array(
            'title' => 'QLS bedrijfs-id (zie id url achter `company/` in MijnQLS)',
            'type' => 'text',
            'placeholder' => 'Company id',
            'description' => 'Indien ingevuld worden de servicepunten gefilterd op de ingeschakelde servicepunten in MijnQLS',
            'desc_tip' => true,
        );
    }
}
