<?php
/**
 * Plugin Name: Pakketdienst QLS Servicepoint Locator
 * Plugin URI: https://pakketdienstqls.nl
 * Description: Pakketdienst QLS Servicepoint Locator plugin
 * Version: 1.3
 * Author: Pakketdienst QLS B.V.
 * Author URI: https://profiles.wordpress.org/pakketdienstqls
 * Requires at least: 4.8.0
 * Tested up to: 4.8.2
 */

if (!defined('ABSPATH')) {
    exit();
}

add_action('plugins_loaded', 'qls_servicepoint_loaded');

function qls_servicepoint_loaded()
{
    add_action('woocommerce_shipping_init', 'qls_servicepoint_shipping_init');
    add_filter('woocommerce_shipping_methods', 'qls_servicepoint_add_service_point_shipping_method');
    add_action('woocommerce_checkout_process', 'qls_servicepoint_checkout_process');
    add_action('woocommerce_after_shipping_rate', 'qls_servicepoint_checkout_company_id');
    add_action('woocommerce_checkout_create_order_shipping_item', 'qls_add_metadata_to_qls_shipment_line');
    add_action('woocommerce_checkout_update_order_meta', 'qls_add_metadata_to_order');
}

function qls_servicepoint_shipping_init()
{
    require_once('includes/methods.php');
}

function qls_servicepoint_add_service_point_shipping_method($methods)
{
    $methods['qlssp'] = 'WC_Qls_Servicepoint_Shipping_Method';
    
    return $methods;
}

function qls_servicepoint_checkout_process()
{
    if (isset($_POST['shipping_method'][0])) {
        $parts = explode(':', sanitize_text_field($_POST['shipping_method'][0]));
    }
    
    if ($parts[0] == 'qlssp' && (!isset($_POST['qls_servicepoint_code']) || empty($_POST['qls_servicepoint_code']))) {
        wc_add_notice('Kies een servicepunt', 'error');
    }
}

function qls_servicepoint_checkout_company_id($method) {
    if ('qlssp' === $method->method_id) {
        $qlsServicePointMethod = new WC_Qls_Servicepoint_Shipping_Method($method->instance_id);
        $companyId = $qlsServicePointMethod->get_option('qls_company_id');

        wp_enqueue_script('qls-servicepoint-locator', 'https://embed.pakketdienstqls.nl/js/woocommerce-servicepoint-locator-v1.js');

        add_action('wp_footer', function () use ($companyId) {
            qls_servicepoint_checkout_footer($companyId);
        });
    }
}

function qls_servicepoint_checkout_footer($companyId = '') {
    echo "<script>
            var companyId = '$companyId';
          </script>";
}

function qls_add_metadata_to_qls_shipment_line($item)
{
    if (isset($_POST['qls_servicepoint_code']) && str_starts_with($_POST['shipping_method'][0], 'qlssp')) {
        $servicePointCode = sanitize_text_field($_POST['qls_servicepoint_code']);

        $item->add_meta_data('_qls_servicepoint_code', $servicePointCode);
        $item->set_name('Afhalen bij afhaalpunt ' . $servicePointCode);
    }
}

function qls_add_metadata_to_order($order_id)
{
    if (isset($_POST['qls_servicepoint_code']) && str_starts_with($_POST['shipping_method'][0], 'qlssp')) {
        $servicePointCode = sanitize_text_field($_POST['qls_servicepoint_code']);

        update_post_meta($order_id, '_qls_servicepoint_code', $servicePointCode);
    }
}